大闹天宫 (豆瓣)
Description: 大闹天宫电影简介和剧情介绍,大闹天宫影评、图片、预告片、影讯、论坛、在线购票
Keywords: 大闹天宫,大闹天宫,大闹天宫影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.53豆瓣电影Top250

# 大闹天宫 (1961)

导演: 万籁鸣
编剧: 李克弱 / 万籁鸣
主演: 邱岳峰 / 富润生 / 毕克 / 尚华 / 于鼎 / 李梓 / 刘广宁
类型: 剧情 / 动画 / 奇幻 / 古装
制片国家/地区: 中国大陆
语言: 汉语普通话
上映日期: 1961(中国大陆) / 1964(中国大陆) / 1978(中国大陆)
片长: 113分钟 / 44分钟(上集) / 69分钟(下集) / 84分钟(40周年纪念版)
又名: 大闹天宫 上下集 / The Monkey King / Havoc in Heaven / Uproar in Heaven
IMDb: tt0059855
豆瓣评分
引用
9.4
408929人评价
5星
74.1%
4星
21.3%
3星
4.1%
2星
0.3%
1星
0.1%
好于 99% 动画片
好于 99% 剧情片
想看 看过
评价:
推荐

## 大闹天宫的剧情简介 · · · · · ·

话说在东土傲来国有一座花果山，山上有一尊石猴吸收日精月华化身为一只神猴（邱岳峰 音），统领着山中的猴子猴孙。为求得一件称心的宝贝，神猴孙大圣潜入龙宫，强硬求来大禹治水时的定海神针如意金箍棒。东海龙王（毕克 音）心有不甘，于是上天将此事诉诸玉帝（富润生 音）。玉皇大帝命令太白金星（尚华 音）下界招安，许以爵位。不知有诈的孙大圣欣然前往，却发现只是负责养马的弼马温。得知受骗的猴王反下天庭，与天兵天将在花果山展开大战……
本片根据古典名著《西游记》中的故事改编，前后历时4年创作，并荣获1962年捷克斯洛伐克卡罗维发利国际电影节短片特别奖、1978年英国伦敦国际电影节年度杰出电影奖、1982年厄瓜多尔第四届国际儿童电影节三等奖、第二届中国电影“百花奖”最佳美术片奖。 ©豆瓣

## 大闹天宫的演职员 · · · · · · ( 全部 28 )

- 万籁鸣 导演
- 邱岳峰 配 齐天大圣
- 富润生 配 玉皇大帝
- 毕克 配 东海龙王/土地公公
- 尚华 配 太白金星
- 于鼎 配 二郎神/托塔天王/马天君/持国天王

## 大闹天宫的视频和图片 · · · · · · ( 视频评论1 · 添加 | 图片718 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  哪吒闹海

  天书奇谭

  天空之城

  幽灵公主

  三个和尚

  风之谷

  小蝌蚪找妈妈

  哈尔的移动城堡

  九色鹿

  玩具总动员

我要写短评

## 大闹天宫的短评 · · · · · · ( 全部 51958 条 )

热门 / 最新 / 好友

### 3643 有用 Over5 看过 2007-03-17 18:46:20

堪比业界史上的两弹一星，这个猴子是我们国产动画片的骄傲，但到了今天依然得指望着它说事儿～

### 3433 有用 有病的乃提乃 看过 2011-04-24 03:57:26

50年过去了，中国动画不进反退，还有比这更可悲的事么。技术上止步不前，创意上才思枯竭。一群羊和两只狼的故事都被反复翻炒出N部，悲矣；当年号称十年巨制制出一部宝莲灯，贻笑大方矣。现在小孩的物质条件比我们好了n倍，但是我仍然觉得当年的我们是幸福的，因为有这么多优秀的动画片陪伴成长。

### 2702 有用 战国客 看过 2009-04-23 18:15:42

向中国早期的动画制作人员致敬！

### 2054 有用 Odding 看过 2006-03-26 14:03:45

这个无须评论。

### 1791 有用 巴喆 看过 2012-10-17 10:55:56

1961年，中国大陆，全手工，此片原画历时4年，10分钟的动画镜头要画7000到1万张原画。文革时期此片被批斗为牛鬼蛇神，是流氓无赖的化身。当时运动每天都在升级，全国的“猴子戏”都被禁演了，万籁鸣也被关起来了。日本“漫画之神”，动画漫画始祖手冢治虫本人承认正是看了万氏兄弟的《铁扇公主》，他才弃医从事动漫事业，才有了后来的《阿童木》。中国的动画曾经领先亚洲，我绝对没夸张。9.5

> 更多短评 51958条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 大闹天宫的影评 · · · · · · ( 全部 248 条 )

热门 / 最新 / 好友
榭风岫晓 2008-01-23 22:37:22

## 大师已矣，后继无人

“1997年10月7日，98岁高龄的万籁鸣安静地离开人世。在老人的墓碑上没有墓志铭，墓碑设计成一卷展开的电影胶片，一座云遮雾绕的花果山，跃出了人见人爱的孙大圣，大圣手搭凉棚，四处眺望。这位中国动画事业的创始人在走过将近一个世纪的岁月后长眠，在他的身边还有那个能够上天... (展开)
540 16 40回应 收起
废柴 2010-03-16 08:00:25

## GJM

“孙悟空，曾组织领导黑社会性质犯罪团伙，于花果山网罗多名社会闲散猴员，从事各类违法活动，造成极其恶劣的影响，严重破坏了当地的社会秩序。在实施抓捕过程中，其多次暴力抗法，公然向我天庭挑衅。我天庭表现出了极强的克制力，以退为进，极大打击了其嚣张气焰，终将其逮捕... (展开)
293 29 29回应 收起
爱丽丝小盆友 2009-07-09 01:33:09

## 60年代的好莱坞

要不怎么说我靠驴子过活呢。好东西多啊没办法。就恨硬盘不够大。 同一天里看了两部片子，一部是上届奥斯卡大赢家《老无所依》，没看懂……气不过，遂翻出《大闹天宫》来过瘾。 看《大闹天宫》就跟看大片似的，过瘾！ 虽说是不记得上次看是几时了，不过这真是一部让人拍案叫绝... (展开)
104 8 17回应 收起
橙曦羽潞 2017-07-18 19:31:11

## 永远的经典

《大闹天宫》的风格也是无可厚非的有特点。影片色彩浓重，造型奇异，场面宏伟，将神佛等在传统造型的基础上做了夸张处理，突出了形象的装饰性和性格的典型性。该片通过独特的艺术构思和表现手法，使原著的思想性和艺术性得到充分展示。 在孙悟空的形象创造上，就寄托了作者的理... (展开)
60 1 2回应 收起
[己注销] 2020-01-24 18:22:27

## 上美的《孙悟空三部曲》，以及手塚治虫

“孙悟空三部曲”指《大闹天宫》(1961)、《人参果》 (1981)、以及《金猴降妖》 (1985)。 [大闹天宫] 《大闹天宫》完整版片长大约110分钟（央视的40周年纪念版只有80分钟），市面上各个版本画质不一样，目前法国修复版、影迷修复版是画质最好的两个版本（这两个版本都是完整的，... (展开)
45 2 1回应 收起
minox 2006-10-25 17:22:47

## 猴妖作乱惊天地

又看了一遍《大闹天宫》，重温童年熟悉的东西总能给人以特别的愉悦，何况是大闹天宫这样的佳构：万氏兄弟的扛鼎之作，中国动画史的颠峰，难以想象这是40年前的作品。现在看来这就是那个年代的大片，万氏导演、张光宇的造型设计、上译的经典配音、美影厂的精兵强将，群贤毕集，... (展开)
63 9 18回应 收起
jfflnzw 2017-05-27 20:39:57

## 不朽的经典

影片《大闹天宫》根据古典文学名著《西游记》前七回改编，是中国文学古典名著《西游记》动画版最好的诠释。导演是中国动画界享有盛誉的万氏兄弟 ，导演万籁鸣根据中国古典神话小说改编，影片分上、下两集，总长11万英尺，放映近两个小时，数十名动画。创作人员历时四年的才完成... (展开)
33 3 1回应 收起
工藤新一 2017-06-08 09:17:00

## 终点才是起点

大闹天宫，孙悟空的巅峰，正如年轻人涉世未深，只想以为自己上天入地无所不能，以为全世界都在自己脚下，以为可以戏弄世间万物，玩弄社会规则与人情世故，以为自己真的跳出三界外不在五行中。所以很多西游题材对这段的渲染大都特别爽快与帅气，因为这情节满足了所有人对自己的... (展开)
46 1 0回应 收起
雪 2017-06-11 19:07:11

## 永恒的记忆

这动画片根本不需要写影评，从年纪小的时候开始看，已经不知道看过多少遍。但无论多少年后，随时拿出来看，依然看得津津有味。 这是国产动画的巅峰之作，是我们在世界动画史上拿出来炫技的作品，也是我们的骄傲。 这个美猴王，那么灵动，那么桀骜不驯，那么神采奕奕，... (展开)
32 1 0回应 收起
咚咚锵 2010-12-02 10:07:40

## 还记得那匹天马

小时候看的，很精彩，到如今，这片子给我印象最深刻的角色不是孙大圣，而是那匹马。 大圣当弼马温时对众天马发出邀请：谁愿意陪我？面对大圣的邀请，别的天马都默然无语，只有它主动出来愿意陪大圣驰骋一番。 那是怎样一个自由骄傲的灵魂啊，有与孙大圣一样的对天宫的不服气，... (展开)
18 1 14回应 收起

> 更多影评 248篇

添加新讨论

## 讨论区 · · · · · ·

这部电影真的很难看 | 来自浮躁 | 9 回应 | 2022-11-19 16:46:02
好喜欢齐天大圣 | 来自芝士 |  | 2022-11-19 14:39:38
孙悟空的头上为什么要戴着黄色帽子加束发带（类似... | 来自编号223。 | 1 回应 | 2022-09-16 10:56:48
中国动画再花上二十年，还能有机会与上海美厂相媲... | 来自树枝猫。 | 2 回应 | 2022-08-23 23:26:56
没找到配乐歌单 | 来自日潮三千 | 4 回应 | 2022-08-18 12:04:58

> 去这部影片的讨论区（全部108条）

## 关于《大闹天宫》的问题 · · · · · · ( 全部11个 )

- 是不是仙女都长的一个模样啊？ 3人回答
- 谁有蓝光原盘？？？ 3人回答

> 全部11个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 优酷视频 免费观看
- 爱奇艺视频 免费观看
- 腾讯视频 VIP免费观看
- 1905电影网 免费观看
- 哔哩哔哩 免费观看
- 西瓜视频 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)
- 中文电影250强总榜（1905——2012） (东方快车)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 纱织NaNa
  12分钟前 想看
- 优雅的疯子
  12分钟前 看过
- 不知名选手Du
  15分钟前 看过

743863人看过 / 133320人想看

订阅大闹天宫的评论:
feed: rss 2.0